import logging
import ssl
import skimage as ski
import os.path
import pandas as pd

import src.marcuslion.config
from src.marcuslion.datasets import Datasets
from src.marcuslion.providers import Providers

logger = logging.getLogger()
# logger.setLevel(logging.DEBUG)
logger.addHandler(logging.StreamHandler())

logger.info("Start marcuslion lib")

pd.set_option('display.max_rows', 500)
pd.set_option('display.max_columns', 500)
pd.set_option('display.width', 2000)

resource_path = os.path.join(os.path.split(__file__)[0], "resources")
image = ski.io.imread(resource_path + "/marcus_lion_logo.jpg")
ski.io.imshow(image)

# this required downgrading requests library to urllib3-1.24.3 to avoid SSL cert error
ssl._create_default_https_context = ssl._create_unverified_context


providers = Providers()
datasets = Datasets()


def help1():
    print("  ml.providers.list() or ml.datasets.search()")








import io
import urllib
import urllib3

import pandas as pd

from src.marcuslion.config import base_url, api_key


class Providers:
    """
    MarcusLion Providers class
    """

    @staticmethod
    def list() -> pd.DataFrame:
        """
        Providers.list()
        """
        # $ curl 'https://qa1.marcuslion.com/core/datasets/search?providers=kaggle,usgov&title=bike'
        url = base_url + "/" + 'core/datasets/providers?'
        params = {"apiKey": api_key}
        full_url = url + urllib.parse.urlencode(params)

        # Sending a GET request and getting back response as HTTPResponse object.
        http = urllib3.PoolManager()
        resp = http.request("GET", full_url)
        if resp.status != 200:
            raise ValueError("status: " + url + " -> " + str(resp.status))

        # converting
        string_io = io.StringIO(resp.data.decode())
        return pd.read_json(string_io)

    def query(self):
        """
        Providers.query()
        """
        pass

    def search(self):
        """
        Providers.search()
        """
        pass
